@@ -46,7 +46,7 @@ See https://github.com/BonnieMcLean/IcoTools for more details."""
     # get their feature values
     features={}
     here=os.path.dirname(os.path.abspath(__file__))
-    path=os.path.join(here,'templates','phoiblefeatures.txt')
+    path=os.path.join(here,'features','phoiblefeatures.txt')
     with open(path,"r",encoding="UTF-8") as infile:
         next(infile)
         reader=csv.reader(infile)
@@ -123,7 +123,7 @@ See https://github.com/BonnieMcLean/IcoTools for more details."""
     with open(stimuli,'r',encoding="UTF-8") as infile:
         reader=csv.DictReader(infile)
         headers=reader.fieldnames
-        headers.append("foil")
+        headers.append("foils")
         outlines.append(headers)
         for row in reader:
             word=row["form"]
@@ -168,6 +168,12 @@ See https://github.com/BonnieMcLean/IcoTools for more details."""
             line=list(row.values())
             line[-1]=foil1+"|"+foil2+"|"+foil3
             outlines.append(line)
+
+            # check you didn't miss any characters in your letters file
+            for char in original:
+                if char not in substitutions.keys():
+                    print("WARNING! The letter "+char+" in the word "+original+" was not found in your letters file, so it has not been replaced in the foils!")
+                    print("We recommend you add this letter to the letters file and rerun this program before proceeding.")
         infile.close()
 
                     
